/*-----------------------------------------------------------------
  Released under the MIT License  - see
  http://www.opensource.org/licenses/mit-license.php

  LED alarm clock by Jack Botner

  main.h

  20201212: program written
-----------------------------------------------------------------*/
#ifndef _MAIN_H_
#define _MAIN_H_

#include "common.h"

// Timer counter initializations
#define INIT_CTR0			( 256 - 63 )
#define INIT_CTR1			( 65536 - 31250 )
#define INIT_CTR2			( 256 - 52 )   // was 26

#define LED_TIME_SLICES     120      // number of LED digit time slices

#define MAX_CHECKS       	5        // number of tests before a switch is debounced

#undef WANT_WDT                      // define this to enable the WDT

// Events bits
#define EVENT_BUTTON_PRESSED	1
#define EVENT_ENCODER_CW	    2
#define EVENT_ENCODER_CCW	    3
#define EVENT_HALFSEC		    4
#define EVENT_UPDATE_EEPROM     5
#define EVENT_ADC_COMPLETE      6
#define EVENT_1MS               7

// Debounced switches bits
#define ENC_SWITCH_A			0
#define ENC_SWITCH_B			1
#define ENC_SWITCH_PB			2

// Rotary encoder port defines
#define ENCODER_PORT			PINA
#define ENCODER_A				PA0
#define ENCODER_B				PA1
#define ENC_SW_PORT				PINA
#define ENC_SW_PB				PA2

// Beeper port defines
#define SPEAKER_PORT			PORTC
#define SPEAKER_PIN				PC4

// LED COLON defines
#define COLON_PORT				PORTC
#define COLON_PIN				PC5

// Other defines
#define ALARM_OFF				0
#define ALARM_ON_QUIET			1
#define ALARM_ON_ACTIVE			2

//#define BLINK_NONE			0
//#define BLINK_HOURS			1
//#define BLINK_MINUTES			2
 
// EEPROM stuff
typedef struct _MY_EEPROM_DATA
{
  uint8_t   ucAlarmHrs;
  uint8_t   ucAlarmMns;
  uint8_t   ucAlrmPm;
  uint8_t   ucAlarm_State;
}
MY_EEPROM_DATA;

// Functions

void display_led( uint8_t ucH, uint8_t ucM, uint8_t ucP );
void encoder(void);
void program_clock(void);

#endif  //_MAIN_H_
